import { compact } from '../../util/array.js';
import { basename } from '../../util/path.js';
import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
import { resolveName, api } from './helpers.js';
const NAME = 'Babel';
const ENABLERS = [/^@babel\//];
const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
const CONFIG_FILE_PATTERNS = [
    'babel.config.{json,js,cjs,mjs,cts}',
    '.babelrc.{json,js,cjs,mjs,cts}',
    '.babelrc',
    'package.json',
];
const getName = (value) => typeof value === 'string' ? [value] : Array.isArray(value) ? [value[0]] : [];
export const getDependenciesFromConfig = (config) => {
    const presets = config.presets?.flatMap(getName).map(name => resolveName(name, 'preset')) ?? [];
    const plugins = config.plugins?.flatMap(getName).map(name => resolveName(name, 'plugin')) ?? [];
    const nested = config.env ? Object.values(config.env).flatMap(getDependenciesFromConfig) : [];
    return compact([...presets, ...plugins, ...nested]);
};
const findBabelDependencies = async (configFilePath, { manifest, isProduction }) => {
    if (isProduction)
        return [];
    let localConfig = basename(configFilePath) === 'package.json' ? manifest.babel : await load(configFilePath);
    if (typeof localConfig === 'function')
        localConfig = localConfig(api);
    if (!localConfig)
        return [];
    return getDependenciesFromConfig(localConfig);
};
const findDependencies = timerify(findBabelDependencies);
export default {
    NAME,
    ENABLERS,
    isEnabled,
    CONFIG_FILE_PATTERNS,
    findDependencies,
};
