import { timerify } from '../../util/Performance.js';
import { hasDependency } from '../../util/plugin.js';
import { toEntryPattern, toProductionEntryPattern } from '../../util/protocols.js';
const NAME = 'Eleventy';
const ENABLERS = ['@11ty/eleventy'];
const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
const ENTRY_FILE_PATTERNS = ['.eleventy.js', 'eleventy.config.{js,cjs}'];
const PRODUCTION_ENTRY_FILE_PATTERNS = ['posts/**/*.11tydata.js', '_data/**/*.{js,cjs,mjs}'];
const findEleventyDependencies = async (configFilePath, options) => {
    const { config } = options;
    return config.entry
        ? config.entry.map(toProductionEntryPattern)
        : [...ENTRY_FILE_PATTERNS.map(toEntryPattern), ...PRODUCTION_ENTRY_FILE_PATTERNS.map(toProductionEntryPattern)];
};
const findDependencies = timerify(findEleventyDependencies);
export default {
    NAME,
    ENABLERS,
    isEnabled,
    ENTRY_FILE_PATTERNS,
    PRODUCTION_ENTRY_FILE_PATTERNS,
    findDependencies,
};
