import { basename } from '../../util/path.js';
import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
const NAME = 'Remark';
const ENABLERS = ['remark-cli'];
const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
const PACKAGE_JSON_PATH = 'remarkConfig';
const CONFIG_FILE_PATTERNS = [
    'package.json',
    '.remarkrc',
    '.remarkrc.json',
    '.remarkrc.{js,cjs,mjs}',
    '.remarkrc.{yml,yaml}',
];
const findRemarkDependencies = async (configFilePath, options) => {
    const { manifest, isProduction } = options;
    if (isProduction)
        return [];
    const localConfig = basename(configFilePath) === 'package.json' ? manifest[PACKAGE_JSON_PATH] : await load(configFilePath);
    if (!localConfig)
        return [];
    const plugins = localConfig.plugins
        ?.flatMap(plugin => {
        if (typeof plugin === 'string')
            return plugin;
        if (Array.isArray(plugin) && typeof plugin[0] === 'string')
            return plugin[0];
        return [];
    })
        .map(plugin => (plugin.startsWith('remark-') ? plugin : `remark-${plugin}`)) ?? [];
    return plugins;
};
const findDependencies = timerify(findRemarkDependencies);
export default {
    NAME,
    ENABLERS,
    isEnabled,
    PACKAGE_JSON_PATH,
    CONFIG_FILE_PATTERNS,
    findDependencies,
};
