import { basename } from '../../util/path.js';
import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
const NAME = 'Semantic Release';
const ENABLERS = ['semantic-release'];
const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
const PACKAGE_JSON_PATH = 'release';
const CONFIG_FILE_PATTERNS = [
    '.releaserc',
    '.releaserc.{yaml,yml,json,js,cjs}',
    'release.config.{js,cjs}',
    'package.json',
];
const findSemanticReleaseDependencies = async (configFilePath, options) => {
    const { manifest, isProduction } = options;
    if (isProduction)
        return [];
    const localConfig = basename(configFilePath) === 'package.json' ? manifest[PACKAGE_JSON_PATH] : await load(configFilePath);
    const plugins = (localConfig?.plugins ?? []).map(plugin => (Array.isArray(plugin) ? plugin[0] : plugin));
    return plugins;
};
const findDependencies = timerify(findSemanticReleaseDependencies);
export default {
    NAME,
    ENABLERS,
    isEnabled,
    PACKAGE_JSON_PATH,
    CONFIG_FILE_PATTERNS,
    findDependencies,
};
